“Putting the ‘i’ Back in Team” by Ward P, Coutts AJ, Pruna R, McCall A
_International Journal of Sports Physiology and Performance_
© 2018 Human Kinetics, Inc.

# Note . This article will be published in a forthcoming issue of the International Journal of Sports Physiology and Performance . The article appears here in its accepted, peer-reviewed form, as it was provided by the submitting author. It has not been copyedited, proofread, or formatted by the publisher

**Section:** Invited Commentary

**Article Title:** Putting the ‘i’ Back in Team

**Authors:** Patrick Ward \[1\], Aaron J. Coutts \[2\], Ricard Pruna \[3\], and Alan McCall \[4,5\]

**Affiliations:** \[1\] Seattle Seahawks, Seattle, WA, USA. \[2\] Faculty of Health, University of
Technology Sydney (UTS), Australia. \[3\] FC Barcelona, Barcelona, Spain. \[4\] Arsenal Football
Club, London, UK. \[5\] Edinburgh Napier University, Edinburgh, UK.

**Journal:** _International Journal of Sports Physiology and Performance_

**Acceptance Date:** June 12, 2018

©2018 Human Kinetics, Inc.

**DOI** : [https://doi.org/10.1123/ijspp.2018-0154](https://doi.org/10.1123/ijspp.2018-0154)

“Putting the ‘i’ Back in Team” by Ward P, Coutts AJ, Pruna R, McCall A
_International Journal of Sports Physiology and Performance_
© 2018 Human Kinetics, Inc.

**Title: Putting the** _**‘i’**_ **back in team**

**Authors: Patrick Ward** **\[1\]** **, Aaron J Coutts** **\[2\]** **, Ricard Pruna** **\[3\]** **, Alan McCall** **\[4,5 \]**

**Institution:**

1 Seattle Seahawks, Seattle, USA

2 University of Technology Sydney (UTS), Faculty of Health,, Australia

3 FC Barcelona, Barcelona

4 Arsenal Football Club, London, UK

5 Edinburgh Napier University, Edinburgh, UK

**Corresponding author:**

Alan McCall

Arsenal Football Club
Bell Ln, London Colney
Hertfordshire, AL2 1DR
Tel: +33 651748266 - Fax: +33 320887363

[Email: amccall@arsenal.co.uk](mailto:amccall@arsenal.co.uk)

**Submission type:** Invited commentary

**Running title:** There _is_ an ‘I” in team

**Abstract word count:** 118

**Manuscript word count:** 1914

**Number of figures:** 3

**Number of tables:** 0

“Putting the ‘i’ Back in Team” by Ward P, Coutts AJ, Pruna R, McCall A
_International Journal of Sports Physiology and Performance_
© 2018 Human Kinetics, Inc.

**Abstract**

There is a common expression in sports, that _there is no ‘i’ in team_ . However, there is also a very

important ‘i’ in sports teams - the individual athlete/player. Each player has his/her own unique

characteristics including physical, physiological and psychological traits. Due to these unique

characteristics, each player requires individual provision - whether it be an injury risk profile and

targeted prevention strategy or treatment/rehabilitation for injury, dietary regimen, recovery or

psychological intervention. The aim of this commentary is to highlight how four high-performance

teams from various professional football codes are analysing individual player data.

**Key words:** data analysis, individual, team-sports, athletes, monitoring

“Putting the ‘i’ Back in Team” by Ward P, Coutts AJ, Pruna R, McCall A
_International Journal of Sports Physiology and Performance_
© 2018 Human Kinetics, Inc.

**Introduction**

WIthin high-performance sports organisations, a critical question for science/medicine

practitioners is, ‘how best to analyse, interpret and report monitoring and testing protocols in order to

collaborate with the coaching staff on the design and implementation of the training program for both

individual players and the team as a collective.’ The gold standard is likely to follow an evidence-led

approach \[1,2\] using the integration of coaching expertise, athlete values, and the best relevant research

evidence into the decision-making process for the day-to-day service delivery to players” \[2\] . The aim of

this commentary is to highlight how an evidence-led approach, targeted at the individual player is

currently being integrated by four high-performance teams from various football codes; Association

Football, American Football and Australian Rules Football.

There is a well-known saying in sport; ‘ _there is no ‘i’ in team_ ’, and the current authors argue

that, collectively, there _is_ a very important ‘ _i_ ’ in team – the ‘ _individual’_ . In the current authors affiliated

teams, there are collectively > 150 players from > 20 countries spanning 5 continents. With a variety of

ethnicities, each player with unique physiological and psychological characteristics. Each of these

players requires individual catering - whether an injury risk profile, prevention strategy,

treatment/rehabilitation, dietary regimen, recovery or psychological intervention. It is hoped that this

commentary will provide some insights into innovative practices and begin the discussion and sharing

of ideas of how other teams are integrating an evidence-led approach to optimise the servicing of the

‘
_individual_ . The methods of analysis discussed can supplement the daily interaction with players,

allowing recommendations for modifications to training to be discussed with the coaching staff’.

**Analysing** _**individual**_ **player data**

‘In the sport scientist/medicine practitioners’ daily practice, many decisions are made ‘on the fly’

(i.e. within a short timeframe or even immediately).’ For these practitioners, it is important that they have

confidence in their decision making processes before they provide advice to coaches and/or players. As

practitioners, we typically collect a variety of measurements around a players’ physical capacity, wellness,

injury-risk, rehabilitation progress, training/match performance with the intent to identify and monitor the

individual responses and guide specific treatments and/or interventions. A challenge for practitioners is

“Putting the ‘i’ Back in Team” by Ward P, Coutts AJ, Pruna R, McCall A
_International Journal of Sports Physiology and Performance_
© 2018 Human Kinetics, Inc.

identifying important trends in player’s data and/or deviations from normal patterns. Whilst monitoring

strategies were first reported for individual sport athletes (e.g., endurance sports) as a way to identify risks of

overtraining \[3-6\], this approach has since been adopted by team-sports to guide the training process \[2,7\] . The

information obtained from these measures are commonly used to identify players who are not responding

well to team training, individualising rehabilitation and/or identifying reduced readiness or injury risk \[7\] . In

team sports, individualised monitoring can be particularly challenging when working with individuals given

the number of players in a team and the wide variety of training interventions prescribed each day (i.e. many

players full-training, whilst some are prescribed modified programs within the team session and others in

bespoke rehabilitation away from other team members). In these sports the coaching staff usually develop a

training plan based on the team’s technical/tactical strategies required for the upcoming match. In this way,

the risk is that players on the team can be administered similar field-based training programs, often without

sufficient consideration of how each individual may be tolerating the prescribed training. Even for teams

where players are carefully monitored at the individual level, it can still be difficult to individualise the

training program as available approaches to make inferences at the individual level are not well described in

the literature.

A number of statistical approaches have been reported to identify individual differences across

periods of time in physical therapy, exercise, and elite sport \[8-11\] . The aim of implementing these analyses is to

enhance the decision-making around issues relating to individual athletes. Analytic approaches such as those

drawing from single-subject research design and time series analysis \[12\], or those using a magnitude-based

inference (MBI) approach to analysing the individual \[9,13\] may provide fast thinking sports science and

medicine practitioners with simple methods of analysing individual player data.

_Magnitude-Based Inference for Assessing Individuals_

Magnitude-based inference is a statistical approach that allows the practitioner to interpret the

magnitude of the observed effect, relative to some standardized threshold, as being either substantial or

trivial \[14\] . While initially proposed for making group comparisons, this method has recently been extended to

assessing individuals \[9,13,15\] . Through this approach, practitioners can statistically evaluate the direction of a

“Putting the ‘i’ Back in Team” by Ward P, Coutts AJ, Pruna R, McCall A
_International Journal of Sports Physiology and Performance_
© 2018 Human Kinetics, Inc.

player’s trend and the magnitude of that trend over time \[9\], allowing for more meaningful and evidence-led

conversations with coaches regarding the health, well-being and performance capacity of players.

Through the MBI approach, the practitioner can qualitatively assess the observed effect relative to a

smallest worthwhile change (SWC) \[14\] . Several methods exist for calculating the SWC such as practical

experience in sport, recent publications identifying typical variations in the variable of interest for a similar

level of player, or more commonly, by multiplying the between-subject (player) standard deviation (SD) by

0.2 \[16\] . While this approach may be useful when analysing performance testing data for groups of athletes (e.g.,

vertical jump for athletes in each position group of an American Football team) the magnitude of between

subject SD falls victim to the heterogeneity of the group \[15\] limiting its utility to detect changes when evaluating

serial measures within the individual (e.g., Daily Wellness Questionnaire data). This has led some authors to

determine the SWC from the within-individual coefficient-of-variation (CV), as this approach is not only

individualized to that person’s typical variation but also takes into account the repeated measures structure of

the data \[15\] . For example, Plews and colleagues \[17\] took an individualized MBI approach to evaluate the heart

rate variability (HRV) of elite triathletes during a specific training block. The authors established a SWC in

Ln rMSSD (the natural logarithm of the square root of the mean sum of the squared differences between

adjacent normal R:R intervals) as 0.5\*individual athlete CV and found that a large linear decrease in Ln

rMSSD CV for the athlete’s 7-day rolling average revealed a trend towards non-functional over-reaching \[17\] .

This approach is similar to examining individualized z-scores, a commonly used method in sports science \[18\] .

However, it may be easier for practitioners to explain data to coaches or players/athletes in reference to

percentage changes (e.g. she ran 30% more than usual) rather than explaining data on a standardized scale as

is the case with z-scores. For team sport athletes, using a MBI approach such as we have outlined, would be

appropriate for analysing meaningful changes in training and monitoring data. For example, the training load

and/or wellness response of players on a team can be analysed using a within-individual MBI approach by

applying similar logic to that of Plews and colleagues \[17\] . In doing so, the outcomes can be visualized to show

when meaningful changes in the player’s training plan occur. MBI can also be applied to various other team

monitoring aspects. Figure 1 follows the trend of an individual players’ perceived soreness during 20-weeks

“Putting the ‘i’ Back in Team” by Ward P, Coutts AJ, Pruna R, McCall A
_International Journal of Sports Physiology and Performance_
© 2018 Human Kinetics, Inc.

of preseason training. This type of visualization has been suggested as a positive feature of taking an MBI

approach to data analysis \[13\] .

_Statistical Process Control_

Statistical Process Control (SPC), sometimes referred to as the “two standard deviation band

method”, is a single-subject approach that can be applied by the practitioner to quickly understand a player’s

trend in any type of monitoring data. Taking its roots in industrial quality control, SPC has since been applied

in both social work and physical therapy settings \[11,19\] . The SPC analysis utilizes a control chart, which

visualizes the individual player’s time series data with respect to that individual’s control line (average) and

control limits, often representing 2 SD above and below the mean. Observations, which lie above or below

the upper control limit (UCL) or lower control limit (LCL), are deemed to be “out of statistical control” and

would warrant further investigation. To evaluate whether more subtle shifts in the individual’s trend are taking

place, run time errors can be established to identify, for example, periods of time where several observations

(e.g., 8 or 9) reside above or below the control line indicating a potential shift in the overall process \[19\] . The

versatility of SPC provides the practitioner with options of setting their own UCL and LCL. For example,

instead of 2SD control limit, a practitioner may feel it important to be _alerted_ when a value exceeds 1SD \[8\] .

The control limits may be initially set with general heuristics in mind ( _fast working sports science_ approach),

however, as more data is collected and more detailed analysis is carried out, these should be adjusted to

represent the change that is most meaningful for the given population ( _slow working sports science_ approach).

It is common practice for sports practitioners to use the entire historic data of a player/athlete as their

"mean" and "SD", however, this may be limited given the changes in training demands that take place

throughout a season, for example between the pre- and in-season periods \[20,21\] . Therefore, it might be

more useful to evaluate data that is recent, for example a 28 day mean and SD or to use some form of

rolling average \[22\] .

Figure 2 provides an example of an individual player’s 48 h post-match values from a test of isometric

hamstring force. Amber dots represent when the isometric force values (newtons) drop 1SD below the

player’s mean values and red dots when the force falls beyond 1.5SD. These flags (among other subjective,

“Putting the ‘i’ Back in Team” by Ward P, Coutts AJ, Pruna R, McCall A
_International Journal of Sports Physiology and Performance_
© 2018 Human Kinetics, Inc.

objective physical, psychological and contextual factors) are used to inform the decision-making process for

that player’s training program, recovery intervention and physiotherapy treatment prior to the next match.

_Mixed Models_

One potential limitation of SPC analysis is that several measurements on the individual are

required in order to establish the control line, UCL and LCL. This may be problematic for individuals

who enter the team at different stages of the season (e.g., new players via draft or transfer, trade or free

agent signings) or indeed those with missing data due to poor compliance, technological failure or as

commonly seen when international level players transition from club to national team for major

tournaments. To account for these limitations, while still evaluating individual differences in training,

mixed model analyses have been recommended \[10,23,24\] . These types of models allow the practitioner to

leverage the _“wisdom of the crowd”_ via fixed effects while also analysing individual differences

through the specification of random intercepts and/or slopes \[25\] . In brief, a mixed-model approach

represents a compromise between pooled data (e.g., the average across all observations) and non-pooled

data (e.g., the averages for the individuals themselves, such as SPC) \[25\] . This approach is useful in sports

science where player’s that have a small number of observations may initially be better represented by

the fixed effects until sufficient observations can be obtained. Similarly, those with a substantial amount

of data will have more individualized slope and regression values around the fixed effects of the model.

The random component of these models allow the practitioner to evaluate how much the individual

athlete deviates from the group. Therefore, such a model may be useful for exploring inter-individual

responses that athletes may have to the prescribed training dose.

Mixed-model approaches have begun to find their way into the sports science literature \[20,26,27\] .

However, it is generally uncommon for sports scientists and medicine professionals to discuss random

effects outputs, as most simply interpret the fixed effects portion of the model. Without a more thorough

discussion of the model’s random effects it is challenging to understand the relationship between

individual differences displayed by players. One method to utilize the random effects of the model is to

determine the “effect” of interest based off the between-subject SD \[14\] . The typical within-individual

variation can be used to represent the confidence we place on a change in a player’s value from one

“Putting the ‘i’ Back in Team” by Ward P, Coutts AJ, Pruna R, McCall A
_International Journal of Sports Physiology and Performance_
© 2018 Human Kinetics, Inc.

measurement to the next. This analytic approach can be visualized with a control chart and error bars

around the observed value. Figure 3 shows the difference between observed and predicted session-RPE

(rating of perceived exertion) training loads for a player group, where the prediction came from a mixed

effects model. When the error bars surrounding the value reside outside of the grey area, then we can

be more confident that the change is meaningful and further investigation is warranted (figure 3).

**Take home message**

The intention of this commentary to increase the awareness of practitioners who may not be applying

statistical approaches to better understand individual athletes within a team sport setting. We hope that by

implementing these approaches that the fast-thinking practitioners can make confident decisions at the

individual player level. While, we concede that such approaches will require detailed planning and new skill

sets for many sports practitioners, this is the beginning of the push to better understand individual players and

we feel that this is an ideal opportunity to start on the right foot. It is the philosophy and methods of the current

authors’ affiliated teams to adopt such strategies as and when appropriate to both enhance our sports science

and medicine service to our own individual players. We welcome and encourage other sports practitioners

from teams to share other methods of analysing the individual so that we can learn and improve together.

**Acknowledgments**

The authors would like to acknowledge the sports science, medicine and performance staff of each of the

affiliated teams. In particular, Colin Lewin, Ben Ashworth and Sarah Rudd from Arsenal Football Club.

“Putting the ‘i’ Back in Team” by Ward P, Coutts AJ, Pruna R, McCall A
_International Journal of Sports Physiology and Performance_
© 2018 Human Kinetics, Inc.

**References**

1. Buchheit M. Houston, We Still Have a Problem. Int J Sports Physiol Perform. 2017;12:1111-4.

1. Coutts AJ. Challenges in Developing Evidence-Based Practice in High-Performance Sport. Int J

Sports Physiol Perform. 2017;12:717-8.

3. Foster, C., A. Snyder, and R. Welsh, Monitoring of training, warm up, and performance in athletes,

in Overload, Performance Incompetence and Regeneration in Sport., M. Lehmann, et al.,
Editors. 1999, Kluwer Academic / Plenum Publishers: New York. p. 43-52.

4. Foster, C., et al., Athletic performance in relation to training load. Wisconsin Medical Journal,

1996;95:370-374.

5. Hooper, S.L. and L.T. Mackinnon, Monitoring overtraining in athletes:recommendations. Sports

Medicine, 1995;20:321-327.

6. Rushall, B.S., A tool for measuring stress tolerance in elite athletes. Journal of Applied Sport

Psychology, 1990;9:51-66.

7. Coutts, A.J., S. Crowcroft, and T. Kempton, _Developing athlete monitoring systems: Theoretical_

_basis and practical applications_, in _Sport, Recovery and Performance: Interdisciplinary_
_Insights_, M. Kellmann and B. Beckmann, Editors. 2017, Routledge: Abingdon. p. in press.

8. Sands WA, Kavanaugh AA, Murray SR, McNeal JR, Jemni M. Modern Techniques and

Technologies Applied to Training and Performance Monitoring. 2017;12:S263-272.

9. Hopkins WG. A spreadsheet for monitoring an individuals changes and trends. Sportsci. 2017;21:5

1.

1. Kwok OM, Underhill AT, Berry JW, Luo W, Elliot TR, and Yoon M. Analyzing Longitudinal

Data with Multilevel Models: An Example with Individuals Living with Lower Extremity
Intra-articular Fractures. Rehabil Psychol. 2008;53:370-386.

11. Nourbakhsh MR, and Ottenbacher KJ. The Statistical Analysis of Single-Subject Data: A

Comparative Examination. Phys Ther. 1994;74:768-76.

12. Sands WA, McNeal JR, and Stone M. Plaudits and pitfalls in studying elite athletes. Percept Mot

Skills. 2005;1:22-4.

13. Buchheit M. The numbers will love you back in return – I promise. In J Sports Physiol Perf.

2016;11:551-4.

14. Hopkins WG and Batterham AM. Error rates, decisive outcomes and publication bias with several

inferential methods. Sports Med. 2016;46:1563-73.

15. Buchheit M. Monitoring training status with HR measure: do all roads lead to Rome? Front

Physiol. 2014; doi: 10.3389/fphys.2014.00073

16. van Shaik P and Weston M. Magnitude-based inference and its application in user research. Int J

Human-Computer Studies. 2016;88.38-50.

“Putting the ‘i’ Back in Team” by Ward P, Coutts AJ, Pruna R, McCall A
_International Journal of Sports Physiology and Performance_
© 2018 Human Kinetics, Inc.

17. Plews DJ, Laursen PB, Kilding AE, Buchheit M. Heart rate variability in elite triathletes, is

variation in variability the key to effective training? A case comparison. Sports Med.
2012;112:3729-41.

18 Robertson. S., Bartlett. JD., Gastin. PB. (2017). Red, Amber, or Green? Athlete monitoring in team

sport: The need for decision-support systems. Int J Sports Physiol Perform. 12(Suppl 2):
S273-S279.

19. Orme JG, and Cox ME. Analyzing single-subject design data using statistical process control

charts. Social Work in Research. 2001;25:115-27.

20. Ritchie. D., Hopkins. WG., Buchheit. M., Courdy. J., Bartlett. JD. (2016). Quantification of

training ad competition load across a season in an elite Australian football club. Int J Sports
Physiol Perform. 11(4): 474-479.

21. Moreiera. A., Bilsborough. JC., Sullivan. CJ., CIancosi. M., Coutts. AJ. (2015). Training

periodization of professional Australian football players during an entire Australian Football
League season. Int J Sports Physiol Perform. 10(5): 566-571.

22. Williams. S., West. S., Cross. MJ., Stokes. KA. (2017). Better way to determine the actute:chronic

workload ratio? Br J Sports Med. 51(3): 209-210.

23. Gastin PG, Meyer D, and Robertson D. Perceptions of wellness to monitor adaptive responses to

training and competition in elite Australian Football. J Strength Cond Res. 2013;27:2518-26.

24. Cnaan A, Laird NM, and Slasor P. Using the general linear mixed model to analyse unbalanced

repeated measures and longitudinal data. Statistics in Medicine. 1997;16:2349-80.

25. Gelman A, Hill J. Data analysis using regression and multilevel/hierarchical models. Cambridge

University Press, New York, NY. 2007.

26. Malone JJ, Di Michele R, Morgans R, Burgess D, Morton JP, Drust B. Seasonal Training Load

Quantification in Elite English Premier League Soccer Players. Int J Sports Physiol Perform.
2015;10:489-97.

27. Kempton T and Coutts AJ. Factors affecting exercise intensity in professional rugby league. J Sci

Med Sport. 2016;19:504-8.

“Putting the ‘i’ Back in Team” by Ward P, Coutts AJ, Pruna R, McCall A
_International Journal of Sports Physiology and Performance_
© 2018 Human Kinetics, Inc.

**Figure 1.** An individual player’s perceived soreness during a 20-week pre-season period. Values that
lie beyond the dashed lines are have a 75% chance of a moderate effect (effect size >0.6).

“Putting the ‘i’ Back in Team” by Ward P, Coutts AJ, Pruna R, McCall A
_International Journal of Sports Physiology and Performance_
© 2018 Human Kinetics, Inc.

**Figure 2.** Statistical Process Control chart displaying Match day + 2 (48h) isometric hamstring force
(Left Hamstring at 30 degrees knee flexion). Amber dot represents 1 standard deviation and Red dot
represents 1.5 standard deviations from player mean values. The dotted lines represent the area where
any scores are considered within statistical control. The practitioner can quickly scan each Match day

- 2 testing day and see where a players hamstring isometric force is out with their normal range i.e. outwith statistical control.

“Putting the ‘i’ Back in Team” by Ward P, Coutts AJ, Pruna R, McCall A
_International Journal of Sports Physiology and Performance_
© 2018 Human Kinetics, Inc.

**Figure 3.** Difference between the Observed and Predicted RPE Training Load for players of an
American football team. Predictions were made using a linear effects mixed model. The shaded area
represents a moderate effect relative to the between subject standard deviation. Error bars represent the
within-subject standard deviation from the mixed-model. The practitioner can quickly scan training for
the day and identify any athletes with an abnormal difference between their observed and predicted
responses for this training session.
